<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Management.Setup

Windows Runtime (WinRT) APIs for for the `Windows.Management.Setup` namespace.

This package provides the `winrt.windows.management.setup` module.
